[llvm-commits] CVS: llvm/include/llvm/PassAnalysisSupport.h

Chris Lattner lattner at cs.uiuc.edu
Mon Oct 21 15:01:01 PDT 2002


Changes in directory llvm/include/llvm:

PassAnalysisSupport.h updated: 1.10 -> 1.11

---
Log message:

  - Rename AnalysisUsage::preservesAll to getPreservesAll & preservesCFG to
    setPreservesCFG to be less confusing.


---
Diffs of the changes:

Index: llvm/include/llvm/PassAnalysisSupport.h
diff -u llvm/include/llvm/PassAnalysisSupport.h:1.10 llvm/include/llvm/PassAnalysisSupport.h:1.11
--- llvm/include/llvm/PassAnalysisSupport.h:1.10	Wed Sep 25 16:59:09 2002
+++ llvm/include/llvm/PassAnalysisSupport.h	Mon Oct 21 15:00:19 2002
@@ -61,17 +61,18 @@
 
   // setPreservesAll - Set by analyses that do not transform their input at all
   void setPreservesAll() { PreservesAll = true; }
-  bool preservesAll() const { return PreservesAll; }
+  bool getPreservesAll() const { return PreservesAll; }
 
-  // preservesCFG - This function should be called by the pass, iff they do not:
-  //
-  //  1. Add or remove basic blocks from the function
-  //  2. Modify terminator instructions in any way.
-  //
-  // This function annotates the AnalysisUsage info object to say that analyses
-  // that only depend on the CFG are preserved by this pass.
-  //
-  void preservesCFG();
+  /// setPreservesCFG - This function should be called by the pass, iff they do
+  /// not:
+  ///
+  ///  1. Add or remove basic blocks from the function
+  ///  2. Modify terminator instructions in any way.
+  ///
+  /// This function annotates the AnalysisUsage info object to say that analyses
+  /// that only depend on the CFG are preserved by this pass.
+  ///
+  void setPreservesCFG();
 
   const std::vector<AnalysisID> &getRequiredSet() const { return Required; }
   const std::vector<AnalysisID> &getPreservedSet() const { return Preserved; }





More information about the llvm-commits mailing list